aboutsummaryrefslogtreecommitdiff
path: root/lib/CodeGen/PrologEpilogInserter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/CodeGen/PrologEpilogInserter.cpp')
-rw-r--r--lib/CodeGen/PrologEpilogInserter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/CodeGen/PrologEpilogInserter.cpp b/lib/CodeGen/PrologEpilogInserter.cpp
index 6c3e2d041c..d81ec8bea2 100644
--- a/lib/CodeGen/PrologEpilogInserter.cpp
+++ b/lib/CodeGen/PrologEpilogInserter.cpp
@@ -38,10 +38,10 @@ namespace {
/// frame indexes with appropriate references.
///
bool runOnMachineFunction(MachineFunction &Fn) {
// Get MachineDebugInfo so that we can track the construction of the
// frame.
- if (MachineDebugInfo *DI = getAnalysisToUpdate<MachineDebugInfo>()) {
- Fn.getFrameInfo()->setMachineDebugInfo(DI);
+ if (MachineModuleInfo *MMI = getAnalysisToUpdate<MachineModuleInfo>()) {
+ Fn.getFrameInfo()->setMachineModuleInfo(MMI);
}
// Allow the target machine to make some adjustments to the function
@@ -38,10 +38,10 @@ namespace {
///
bool runOnMachineFunction(MachineFunction &Fn) {
- // Get MachineDebugInfo so that we can track the construction of the
+ // Get MachineModuleInfo so that we can track the construction of the
// frame.